# workload-api-server

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>de.uulm.omi.dbms.workload</groupId>
    <artifactId>workload-api-server</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "de.uulm.omi.dbms.workload:workload-api-server:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/workload-api-server-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import de.uulm.omi.dbms.workload.client.*;
import de.uulm.omi.dbms.workload.client.auth.*;
import de.uulm.omi.cloudiator.dbms.evaluator.model.*;
import de.uulm.omi.dbms.workload.api.DefaultApi;

import java.io.File;
import java.util.*;

public class DefaultApiExample {

    public static void main(String[] args) {
        
        DefaultApi apiInstance = new DefaultApi();
        String taskId = "taskId_example"; // String | the id of the worklaod execution task, used as prefix for result files
        String workloadType = "workloadType_example"; // String | workload type of the result file
        try {
            File result = apiInstance.workloadResultGet(taskId, workloadType);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling DefaultApi#workloadResultGet");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**workloadResultGet**](docs/DefaultApi.md#workloadResultGet) | **GET** /workload/result | get the result file of a workload task
*DefaultApi* | [**workloadStatusGet**](docs/DefaultApi.md#workloadStatusGet) | **GET** /workload/status | get the current state of the workloadProcess
*DefaultApi* | [**workloadTpccPost**](docs/DefaultApi.md#workloadTpccPost) | **POST** /workload/tpcc | starts a TPC-C workload against a relational DBMS
*DefaultApi* | [**workloadYcsbPost**](docs/DefaultApi.md#workloadYcsbPost) | **POST** /workload/ycsb | start a YCSB workload against the provided database


## Documentation for Models

 - [DBEndpoint](docs/DBEndpoint.md)
 - [DBEndpoints](docs/DBEndpoints.md)
 - [DatabaseConfig](docs/DatabaseConfig.md)
 - [DatabaseConfigProperty](docs/DatabaseConfigProperty.md)
 - [Error](docs/Error.md)
 - [MeasurementConfig](docs/MeasurementConfig.md)
 - [ProcessStatus](docs/ProcessStatus.md)
 - [TPCCWorkload](docs/TPCCWorkload.md)
 - [TPCCWorkloadConfig](docs/TPCCWorkloadConfig.md)
 - [WorkloadConfig](docs/WorkloadConfig.md)
 - [WorkloadProcessInstance](docs/WorkloadProcessInstance.md)
 - [WorkloadProcessSubmissionError](docs/WorkloadProcessSubmissionError.md)
 - [YCSBWorkload](docs/YCSBWorkload.md)


## Documentation for Authorization

All endpoints do not require authorization.
Authentication schemes defined for the API:

## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author



