# DefaultApi

All URIs are relative to *http://localhost/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**workloadResultGet**](DefaultApi.md#workloadResultGet) | **GET** /workload/result | get the result file of a workload task
[**workloadStatusGet**](DefaultApi.md#workloadStatusGet) | **GET** /workload/status | get the current state of the workloadProcess
[**workloadTpccPost**](DefaultApi.md#workloadTpccPost) | **POST** /workload/tpcc | starts a TPC-C workload against a relational DBMS
[**workloadTsbsExecuteQueriesPost**](DefaultApi.md#workloadTsbsExecuteQueriesPost) | **POST** /workload/tsbs/executeQueries | executes TSBS queries based on the loaded data
[**workloadTsbsGenerateDataPost**](DefaultApi.md#workloadTsbsGenerateDataPost) | **POST** /workload/tsbs/generateData | generates the TSBS data
[**workloadTsbsGenerateQueriesPost**](DefaultApi.md#workloadTsbsGenerateQueriesPost) | **POST** /workload/tsbs/generateQueries | generates the TSBS quires in the DBMS-specific format
[**workloadTsbsLoadDataPost**](DefaultApi.md#workloadTsbsLoadDataPost) | **POST** /workload/tsbs/loadData | loads the data in the specified timeseries DBMS
[**workloadYcsbPost**](DefaultApi.md#workloadYcsbPost) | **POST** /workload/ycsb | start a YCSB workload against the provided database


<a name="workloadResultGet"></a>
# **workloadResultGet**
> File workloadResultGet(taskId, workloadType)

get the result file of a workload task

Start a YCSB for the specified database 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the worklaod execution task, used as prefix for result files
String workloadType = "workloadType_example"; // String | workload type of the result file
try {
    File result = apiInstance.workloadResultGet(taskId, workloadType);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadResultGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the worklaod execution task, used as prefix for result files |
 **workloadType** | **String**| workload type of the result file | [enum: YCSB, TPCC, TSBS]

### Return type

[**File**](File.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: text/plain

<a name="workloadStatusGet"></a>
# **workloadStatusGet**
> WorkloadProcessInstance workloadStatusGet(applicationInstanceId)

get the current state of the workloadProcess

Start a YCSB for the specified database 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String applicationInstanceId = "applicationInstanceId_example"; // String | the applicationInstanceI of the deployed DB cluster via Cloudiator
try {
    WorkloadProcessInstance result = apiInstance.workloadStatusGet(applicationInstanceId);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadStatusGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **applicationInstanceId** | **String**| the applicationInstanceI of the deployed DB cluster via Cloudiator | [optional]

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadTpccPost"></a>
# **workloadTpccPost**
> WorkloadProcessInstance workloadTpccPost(taskId, workload)

starts a TPC-C workload against a relational DBMS

Start a TPC-C worklaod for the specified database based on the TPC-C implementation of cockroachdb 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the worklaod execution task, used as prefix for result files
TPCCWorkload workload = new TPCCWorkload(); // TPCCWorkload | the TPC-C workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadTpccPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadTpccPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the worklaod execution task, used as prefix for result files |
 **workload** | [**TPCCWorkload**](TPCCWorkload.md)| the TPC-C workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadTsbsExecuteQueriesPost"></a>
# **workloadTsbsExecuteQueriesPost**
> WorkloadProcessInstance workloadTsbsExecuteQueriesPost(taskId, workload)

executes TSBS queries based on the loaded data

Execute queries 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the workload execution task, used as prefix for result files
TSBSWorkload workload = new TSBSWorkload(); // TSBSWorkload | the TSBS workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadTsbsExecuteQueriesPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadTsbsExecuteQueriesPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the workload execution task, used as prefix for result files |
 **workload** | [**TSBSWorkload**](TSBSWorkload.md)| the TSBS workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadTsbsGenerateDataPost"></a>
# **workloadTsbsGenerateDataPost**
> WorkloadProcessInstance workloadTsbsGenerateDataPost(taskId, workload)

generates the TSBS data

Generate data 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the workload execution task, used as prefix for result files
TSBSWorkload workload = new TSBSWorkload(); // TSBSWorkload | the TSBS workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadTsbsGenerateDataPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadTsbsGenerateDataPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the workload execution task, used as prefix for result files |
 **workload** | [**TSBSWorkload**](TSBSWorkload.md)| the TSBS workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadTsbsGenerateQueriesPost"></a>
# **workloadTsbsGenerateQueriesPost**
> WorkloadProcessInstance workloadTsbsGenerateQueriesPost(taskId, workload)

generates the TSBS quires in the DBMS-specific format

Generate TSBS queries 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the workload execution task, used as prefix for result files
TSBSWorkload workload = new TSBSWorkload(); // TSBSWorkload | the TSBS workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadTsbsGenerateQueriesPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadTsbsGenerateQueriesPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the workload execution task, used as prefix for result files |
 **workload** | [**TSBSWorkload**](TSBSWorkload.md)| the TSBS workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadTsbsLoadDataPost"></a>
# **workloadTsbsLoadDataPost**
> WorkloadProcessInstance workloadTsbsLoadDataPost(taskId, workload)

loads the data in the specified timeseries DBMS

Load data 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the workload execution task, used as prefix for result files
TSBSWorkload workload = new TSBSWorkload(); // TSBSWorkload | the TSBS workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadTsbsLoadDataPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadTsbsLoadDataPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the workload execution task, used as prefix for result files |
 **workload** | [**TSBSWorkload**](TSBSWorkload.md)| the TSBS workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="workloadYcsbPost"></a>
# **workloadYcsbPost**
> WorkloadProcessInstance workloadYcsbPost(taskId, workload)

start a YCSB workload against the provided database

Start a YCSB for the specified database 

### Example
```java
// Import classes:
//import de.uulm.omi.dbms.workload.client.ApiException;
//import de.uulm.omi.dbms.workload.api.DefaultApi;


DefaultApi apiInstance = new DefaultApi();
String taskId = "taskId_example"; // String | the id of the worklaod execution task, used as prefix for result files
YCSBWorkload workload = new YCSBWorkload(); // YCSBWorkload | the YCSB workload configuration
try {
    WorkloadProcessInstance result = apiInstance.workloadYcsbPost(taskId, workload);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling DefaultApi#workloadYcsbPost");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **taskId** | **String**| the id of the worklaod execution task, used as prefix for result files |
 **workload** | [**YCSBWorkload**](YCSBWorkload.md)| the YCSB workload configuration |

### Return type

[**WorkloadProcessInstance**](WorkloadProcessInstance.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

